exceptiontools.IntervalError
============================

.. abjad-lineage:: abjad.tools.exceptiontools.IntervalError.IntervalError

.. autoclass:: abjad.tools.exceptiontools.IntervalError.IntervalError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__unicode__
   :noindex:
